<?php

namespace Drupal\saml_sp\SAML;

use OneLogin_Saml2_Auth;
use Drupal\Core\Url;
use Drupal\Core\Link;
use XMLSecurityKey;

class SamlSPAuth extends OneLogin_Saml2_Auth {
  public $auth_callback;

  /**
   * Set the auth callback for after the response is returned
   */
  public function setAuthCallback($callback) {
    $this->auth_callback = $callback;
  }

  /**
    * Initiates the SSO process.
    *
    * @param string $returnTo   The target URL the user should be returned to after login.
    * @param array  $parameters Extra parameters to be added to the GET
    */
   public function login($returnTo = NULL, $parameters = array(), $forceAuthn = FALSE, $isPassive = FALSE, $stay=FALSE, $setNameIdPolicy = TRUE) {
    assert('is_array($parameters)');

    $authnRequest = new SamlSPAuthnRequest($this->getSettings(), $forceAuthn, $isPassive, $setNameIdPolicy);
    $this->_lastRequestID = $authnRequest->getId();

    $samlRequest = $authnRequest->getRequest();
    $parameters['SAMLRequest'] = $samlRequest;
    if (!empty($returnTo)) {
      $parameters['RelayState'] = $returnTo;
    } else {
      $parameters['RelayState'] = OneLogin_Saml2_Utils::getSelfRoutedURLNoQuery();
    }
    $security = $this->getSettings()->getSecurityData();
    if (isset($security['authnRequestsSigned']) && $security['authnRequestsSigned']) {
      $signature = $this->buildRequestSignature($samlRequest, $parameters['RelayState'], $security['signatureAlgorithm']);
      $parameters['SigAlg'] = $security['signatureAlgorithm'];
      $parameters['Signature'] = $signature;
    }
    // get this necessary information for this IdP
    $idp = (object) $this->getSettings()->getIdPData();
    $all_idps = saml_sp__load_all_idps();
    foreach ($all_idps AS $this_idp) {
      if ($this_idp->entity_id == $idp->entityId) {
        $idp->id = $this_idp->id;
      }
    }
    // record the outbound Id of the request
    $id = $authnRequest->getId();
    saml_sp__track_request($id, $idp, $this->auth_callback);
    if (\Drupal::config('saml_sp.settings')->get('debug') && \Drupal::moduleHandler()->moduleExists('devel')) {
      dpm('$parameters');dpm($parameters);
      $url = Url::fromUri($this->getSSOurl(), array('query' => $parameters));
      return [
        'message' => [
          '#markup' => t('This is a debug page, you can proceed by clicking the following link.') . ' ',
        ],
        'link' =>  Link::fromTextAndUrl(t('test link'), $url)->toRenderable(),
      ];
      //return t('This is a debug page, you can proceed by clicking this link. <a href="@url">@url</a>', array('@url' => ));
    }
    $this->redirectTo($this->getSSOurl(), $parameters);
  }

  public function buildRequestSignature($samlRequest, $relayState, $signAlgorithm = XMLSecurityKey::RSA_SHA1) {
    if (\Drupal::config('saml_sp.settings')->get('debug') && \Drupal::moduleHandler()->moduleExists('devel')) {
      dpm('$this->getSettings()->getSecurityData()');
      dpm($this->getSettings()->getSecurityData());
    }
    return parent::buildRequestSignature($samlRequest, $relayState, $signAlgorithm);
  }
}
